@@ -1,5 +1,8 @@
+#ifndef JUPP_BUILTIN_H
+#define JUPP_BUILTIN_H
+
 #ifdef EXTERN_RC_C
-__IDSTRING(rcsid_builtin_h, "$MirOS: contrib/code/jupp/builtin.h,v 1.6 2018/01/08 00:08:18 tg Exp $");
+__IDSTRING(rcsid_builtin_h, "$MirOS: contrib/code/jupp/builtin.h,v 1.7 2020/03/27 06:38:55 tg Exp $");
 #endif
 
 /* Support for built-in config files */
@@ -14,3 +17,5 @@ unsigned char *jfgets(unsigned char *buf,int len,JFILE *f);
 int jfclose(JFILE *f);
 
 extern const unsigned char * const builtins[];
+
+#endif
