@@ -1,4 +1,3 @@
-/* $MirOS: contrib/code/jupp/hash.c,v 1.3 2017/01/10 19:16:27 tg Exp $ */
 /*
  *	Simple hash table
  *	Copyright
@@ -9,6 +8,8 @@
 #include "config.h"
 #include "types.h"
 
+__RCSID("$MirOS: contrib/code/jupp/hash.c,v 1.7 2018/01/07 23:51:34 tg Exp $");
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -19,7 +20,7 @@
 
 static HENTRY *freentry = NULL;
 
-unsigned long hash(unsigned char *s)
+unsigned long hash(const unsigned char *s)
 {
 	unsigned long accu = 0;
 
@@ -31,27 +32,27 @@ unsigned long hash(unsigned char *s)
 
 HASH *htmk(int len)
 {
-	HASH *t = (HASH *) joe_malloc(sizeof(HASH));
+	HASH *t = malloc(sizeof(HASH));
 
 	t->len = len - 1;
-	t->tab = (HENTRY **) joe_calloc(sizeof(HENTRY *), len);
+	t->tab = calloc(len, sizeof(HENTRY *));
 	return t;
 }
 
 void htrm(HASH *ht)
 {
-	joe_free(ht->tab);
-	joe_free(ht);
+	free(ht->tab);
+	free(ht);
 }
 
-void *htadd(HASH *ht, unsigned char *name, void *val)
+void *htadd(HASH *ht, const unsigned char *name, void *val)
 {
 	int idx = hash(name) & ht->len;
 	HENTRY *entry;
 	int x;
 
 	if (!freentry) {
-		entry = (HENTRY *) joe_malloc(sizeof(HENTRY) *64);
+		entry = ralloc(64, sizeof(HENTRY));
 		for (x = 0; x != 64; ++x) {
 			entry[x].next = freentry;
 			freentry = entry + x;
@@ -65,7 +66,7 @@ void *htadd(HASH *ht, unsigned char *name, void *val)
 	return entry->val = val;
 }
 
-void *htfind(HASH *ht, unsigned char *name)
+void *htfind(HASH *ht, const unsigned char *name)
 {
 	HENTRY *e;
 
