@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_QW_H
-#define _JOE_QW_H 1
+#ifndef JUPP_QW_H
+#define JUPP_QW_H
 
 #ifdef EXTERN_UFILE_C
-__IDSTRING(rcsid_qw_h, "$MirOS: contrib/code/jupp/qw.h,v 1.7 2018/01/06 00:28:32 tg Exp $");
+__IDSTRING(rcsid_qw_h, "$MirOS: contrib/code/jupp/qw.h,v 1.8 2020/03/27 06:38:57 tg Exp $");
 #endif
 
 /* QW *mkqw(W *w, char *prompt, int (*func)(), int (*abrt)(), void *object);
