@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_UBLOCK_H
-#define _JOE_UBLOCK_H 1
+#ifndef JUPP_UBLOCK_H
+#define JUPP_UBLOCK_H
 
 #ifdef EXTERN_CMD_C
-__IDSTRING(rcsid_ublock_h, "$MirOS: contrib/code/jupp/ublock.h,v 1.5 2017/12/06 21:17:01 tg Exp $");
+__IDSTRING(rcsid_ublock_h, "$MirOS: contrib/code/jupp/ublock.h,v 1.6 2020/03/27 06:38:59 tg Exp $");
 #endif
 
 extern int square;
