@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_UISRCH_H
-#define _JOE_UISRCH_H 1
+#ifndef JUPP_UISRCH_H
+#define JUPP_UISRCH_H
 
 #ifdef EXTERN_CMD_C
-__IDSTRING(rcsid_uisrch_h, "$MirOS: contrib/code/jupp/uisrch.h,v 1.5 2017/12/06 21:17:02 tg Exp $");
+__IDSTRING(rcsid_uisrch_h, "$MirOS: contrib/code/jupp/uisrch.h,v 1.6 2020/03/27 06:38:59 tg Exp $");
 #endif
 
 int uisrch(BW *bw);
